/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file Client side Web Part manifest definition.
 */
import { IClientSideComponentManifest, ILocalizedString } from './IClientSideComponentManifest';
/**
 * The client side SharePoint framework identifies a Web Part by its manifest. All Web Parts are expected to have a
 *  manifest. The manifest is a schematized JSON blob that is used in multiple parts of the SharePoint infrastructure
 *  to identify, load and process a Web Part. The schema for this manifest is completely owned and versioned by
 *  Microsoft. There are some required properties in the manifest and some optional properties. Optional properties
 *  need to be provided only if the Web Part needs the specific functionality. An invalid manifest could lead to issues
 *  with Web Part loading and functionality problems.
 *
 * @public
 * @betadocumentation - (SPPPLAT VSO#218656)
 */
export interface IClientSideWebPartManifest<TProperties> extends IClientSideComponentManifest, IClientSideWebPartManifestSharedProperties {
    /**
     * Definition: If true, this web part is disabled on Classic Sharepoint pages ?
     * Usage: Certain web parts may not be required on or apply to Classic Sharepoint pages. This flag helps control
     *  that. If this flag is true, the web part will not appear in the classic page web part gallery.
     * Required: no
     * Type: boolean
     * Example: false
     */
    disabledOnClassicSharepoint?: boolean;
    /**
     * Definition: A Web Part can have pre-configured properties like the title, description, toolbox group name and Web
     *  Part specific custom properties. And there can be multiple instances of these pre-configured properties. This
     *  helps support scenarios where an organization may want to present multiple pre-configured entries for a Web Part
     *  in the Toolbox. Each entry is expected to configure the Web Part with a different set of pre-configured
     *  properties. A developer may decide to seed some initial values for these properties but an organization admin can
     *  go ahead and customize these properties per the needs of his/her organization. The properties can also be modified
     *  by the author of the page.
     * Usage: help display a Web Part in the Tooblox, PropertyPane and the initial rendering of the Web Part.
     * Required: yes
     * Type: JSON object
     * Localized: Depends on the property.
     * Supported values: Array of IClientSideWebPartManifestEntry objects.
     * Example:
     *   "[{
     *      title:"Image Web Part",
     *      description: "This Web Part displays an image",
     *      group: "Media",
     *      iconFontName: "image",
     *      properties: {
     *        imageSource: "https://contoso.akamaihd.net/files/mountRainier.jpg",
     *        captionText: "Mount Rainier"
     *      }
     *    }]"
     */
    preconfiguredEntries: IClientSideWebPartManifestEntry<TProperties>[];
}
/**
 * Manifest that is relevant to a Web Part instance.
 *
 * @public
 */
export interface IClientSideWebPartManifestInstance<TProperties> extends IClientSideComponentManifest, IClientSideWebPartManifestSharedProperties {
}
/**
 * This interface specifies the set of properties that can be pre-configured by a Web Part developer. Each
 * pre-configured instance of the Web Part will need a copy of these properties. Organization admins and
 * content authors can modify these properties on a need basis.
 *
 * @public
 */
export interface IClientSideWebPartManifestEntry<TProperties> {
    /**
     * Definition: Title of the web part represented as a single a dictionary of locale keys to title values. This
     *  value will be displayed to the user in the toolbox. This title should be used in the Toolbox and other display
     *  areas. The Web Part developer may give an initial title to the webpart. The organization admin and page author
     *  will have the ability to change this title as per need.
     * Usage: display the name of the webpart in the toolbox, webpart gallery and the page.
     * Required: yes
     * Type: Object
     * Localized: yes
     * Supported values: a dictionary of locale keys to strings. Should always have a 'default' key.
     * Example: "My Webpart"
     *          {
     *            "default": "My WebPart"
     *            "en-us": "My WebPart",
     *            "fr-fr": "Ma WebPart",
     *            "zh": "我的 web 部件"
     *          }
     */
    title: ILocalizedString;
    /**
     * Definition: Description of the web part represented as a dictionary of locale keys to description values. This
     *  value will be displayed to the user in the toolbox. This description should be used in the Toolbox tooltip and
     *  other display areas. The Web Part developer may give an initial description to the webpart. The organization admin
     *  and page author will have the ability to change this description as per need.
     * Usage: display the description of the webpart in the toolbox tooltip, webpart gallery and the page.
     * Required: yes
     * Type: Object
     * Localized: yes
     * Supported values: a dictionary of locale keys to strings. Should always have a 'default' key.
     * Example: "A tool for displaying neat information."
     *          {
     *            "default": "A tool for displaying neat information.",
     *            "en-us": "A tool for displaying neat information.",
     *            "fr-fr": "Un outil d’affichage des informations soignées.",
     *            "zh": "用於顯示整潔資訊的工具。"
     *          }
     */
    description: ILocalizedString;
    /**
     * Definition: The icon for the Web Part, to be displayed in the toolbox, represented as a character name in the
     *  Office 365 icon font file. The icon font is specified here: http://o365icons.cloudapp.net/. If this field has
     *  a value, the '{@link iconImageUrl}' field will be ignored.
     * Required: no
     * Type: string
     * Localized: no
     * Supported values: Any character name in the Office 365 Icon Font.
     * Example: "graph"
     */
    officeFabricIconFontName?: string;
    /**
     * Definition: The icon for the WebPart, to be displayed in the toolbox, represented an image URL. The image at the
     *  URL must be exactly 38x38 px (SPPPLAT VSO#218660 to fix the size of the icon image).
     *  If the '{@link officeFabricIconFontName}' field does not have a value, this field must have a value.
     * Required: no
     * Type: string
     * Localized: no
     * Supported values: Any absolute URL.
     * Example: "https://contoso.akamaihd.net/files/myWebpartIcon.png"
     */
    iconImageUrl?: string;
    groupId: string;
    /**
     * @todo - does this group also affect the webpart gallery in the ClassicPage scenario
     *
     * Definition: This field is used to help decide the Toolbox group for the Web Part in the authoring
     *  experience. In the server rendered page, the Web Part gallery is equivalent of the Toolbox. If no value is
     *  provided, the Web Part will be displayed in the "Custom" group.
     * Usage: display of the Web Part icon in a specific group in the authoring toolbox.
     * Required: no
     * Localized: yes
     * Supported values: string
     * Example: { "default": "Media Web Parts" }
     *
     * @beta
     */
    group?: ILocalizedString;
    /**
     * Definition: every Web Part is expected to have some custom properties. e.g. an image Web Part may have the image
     *  url and caption text as custom properties, a list Web Part may have the list id and list title as custom
     *  properties, and so on. The Web Part framework is transparent to these properties. It just acts as a conduit to
     *  pass these properties in and out to the Web Parts. The Web Part developer fully controls the schema of these
     *  properties. The Web Part developer should follow versioning rules (@todo: pointer to Web Part versioning document)
     *  to evolve these properties.
     *
     * Usage: rendering of the Web Part.
     * Required: yes
     * Localized: no
     * Supported values: any
     * Example: {"imageSource": "https://contoso.akamaihd.net/files/contosoLogo.jpg", "captionText": "Contoso logo"}"
     */
    properties: TProperties;
}
/**
 * This interface specifies the set of common properties that are shared between all instances of the Web Part.
 *
 * @todo: refactor this to a structure based model (SPPPLAT VSO#218544).
 *
 * @beta
 */
export interface IClientSideWebPartManifestSharedProperties {
    /**
     * Definition: List of names of Web Part properties that need to be indexed for search.
     * Usage: extract the specified value properties on the server and provide them to the search indexer.
     * Required: no. If not provided, no values are indexed.
     * Type: string array
     * Values: the strings in the array are expected to be JSONPath for the object properties.
     *         (http://goessner.net/articles/JsonPath/)
     * Supported values: any property names
     * Example: ["text"]
     */
    searchablePropertyNames?: string[];
    /**
     * Definition: List of names of Web Part properties that are links and need to be link fixed up.
     *  Link fixup is a SharePoint feature to help make sure SharePoint internal links in the content
     *  are correct. Pages and content can be moved around within SharePoint site hierarchy.
     * Required: no. If not provided, all values are sanitized
     * Type: string array
     * Values: the strings in the array are expected to be JSONPath for the object properties.
     *         (http://goessner.net/articles/JsonPath/)
     * Supported values: any property names
     * Example: ["destination.url"]
     */
    linkPropertyNames?: string[];
    /**
     * Definition: List of names of Web Part properties that are image sources and need to be link fixed up
     *  and potentially preloaded for performance reasons.
     * Required: no. If not provided, all values are sanitized
     * Type: string array
     * Supported values: any property names
     * Values: the strings in the array are expected to be JSONPath for the object properties.
     *         (http://goessner.net/articles/JsonPath/)
     * Example: ["image[0].source"]
     */
    imageLinkPropertyNames?: string[];
}
